@@ -52,7 +52,7 @@
  ** 									     ** 
  ** ************************************************************************ **/
 
-static char Id[] = "@(#)$Id: 3135c2e8fb9d57a1dba7fa44238e7305a14d5dfe $";
+static char Id[] = "@(#)$Id: 3162fcba5098a1406ec46b2722ec529a971aaa52 $";
 static void *UseId[] = { &UseId, Id };
 
 /** ************************************************************************ **/
@@ -3094,9 +3094,11 @@ EM_RetVal ReturnValue(Tcl_Interp *interp, int retval) {
 		/* found 'EXIT' */
 		Tcl_RegExpRange(exit__expPtr, 1,
 			(CONST84 char **) &startp, (CONST84 char **) &endp);
-		if( startp != '\0')
+		if( startp && *startp != '\0')
 			result = atoi((const char *) startp);
-
+		else
+			result = 0;
+		
 		g_retval = result;
 		em_result = EM_EXIT;
 
